#!/usr/bin/python
'''
author: Tobias Weis

This file converts OpenEXR files saved by blender to other file formats
that are usable with e.g. Python, and create plots of the data for quick visualization.

TODO:
    - relax hardcoded paths (Depth*.exr, Flow*.exr)
    - add more conversions for other modalities
    - relax hardcoded image sizes
'''

import sys,os
import math
import time
import numpy as np
import matplotlib.pyplot as plt
from mpl_toolkits.axes_grid1 import make_axes_locatable
import seaborn as sns
import cv2
import glob
from exr2flow import *

path = sys.argv[1] #<-- path to blenders output files

exr_files = glob.glob(path + "/Depth*.exr")
for fname in exr_files:
    depth = exr2depth(fname, 1920/2, 1080/2)

    fig = plt.figure(figsize=(20,10))
    plt.imshow(depth)

    plt.savefig(path + "/" + fname.split("/")[-1].split(".exr")[0] + ".png")
    np.save(path + "/" + fname.split("/")[-1].split(".exr")[0], depth)

exr_files = glob.glob(path + "/Flow*.exr")


for fname in exr_files:
    print "Loading exr-file: ", fname
    img, bgr, mag, ang = exr2flow(fname, 1920/2, 1080/2)

    fig = plt.figure()
    ax = fig.add_subplot(231)
    plt.title("x-direction")
    im = ax.imshow(img[:,:,0])
    divider = make_axes_locatable(ax)
    cax = divider.append_axes("right", size="5%", pad=0.05)
    plt.colorbar(im, cax=cax)

    ax = fig.add_subplot(232)
    plt.title("y-direction")
    im = ax.imshow(img[:,:,1])
    divider = make_axes_locatable(ax)
    cax = divider.append_axes("right", size="5%", pad=0.05)
    plt.colorbar(im, cax=cax)


    ax = fig.add_subplot(233)
    plt.title("magnitude")
    im = ax.imshow(mag)
    divider = make_axes_locatable(ax)
    cax = divider.append_axes("right", size="5%", pad=0.05)
    plt.colorbar(im, cax=cax)


    ax = fig.add_subplot(234)
    plt.title("angle")
    im = ax.imshow(ang)
    divider = make_axes_locatable(ax)
    cax = divider.append_axes("right", size="5%", pad=0.05)
    plt.colorbar(im, cax=cax)


    fig.add_subplot(235)
    plt.title("visualization")
    plt.imshow(bgr)

    fig.add_subplot(236)
    plt.title("sparse arrows")
    # plot some arrows
    plt.imshow(bgr)
    for x in range(0,bgr.shape[1],50):
        for y in range(0,bgr.shape[0],50):
            plt.arrow(
                    x+img[y,x,0],
                    y+img[y,x,1],
                    -img[y,x,0],
                    img[y,x,1],
                    color='r',
                    width=1.5
                    )

    # save flow-field as numpy-array for testing
    plt.savefig(path + "/" + fname.split("/")[-1].split(".exr")[0] + ".png")
    np.save(path + "/" + fname.split("/")[-1].split(".exr")[0], img)
