"""
Helper functionality to read and convert OpenEXR files
"""
import sys
import array
import OpenEXR
import Imath
import numpy as np
import cv2

def exr2depth(exr, w,h):
    # Open the input file
    file = OpenEXR.InputFile(exr)

    # Compute the size
    dw = file.header()['dataWindow']
    sz = (dw.max.x - dw.min.x + 1, dw.max.y - dw.min.y + 1)

    # Read the three color channels as 32-bit floats
    FLOAT = Imath.PixelType(Imath.PixelType.FLOAT)
    #(R,G,B) = [np.array('f', file.channel(Chan, FLOAT)).tolist() for Chan in ("R", "G", "B") ]
    (R,G,B) = [array.array('f', file.channel(Chan, FLOAT)).tolist() for Chan in ("R", "G", "B") ]

    #R = np.array(R)
    #G = np.array(G)

    img = np.zeros((h,w,3), np.uint8)

    # normalize
    depth = np.array(R)
    print "min before: ", np.min(depth)
    print "max before: ", np.max(depth)
    # cut the total maximum value before rescaling
    maxdepth = 100
    depth[depth > maxdepth] = maxdepth

    depth /= float(maxdepth)
    depth *= 255
    img[:,:,0] = np.array(depth).reshape(img.shape[0],-1)
    img[:,:,1] = np.array(depth).reshape(img.shape[0],-1)
    img[:,:,2] = np.array(depth).reshape(img.shape[0],-1)


    print "min depth: ", np.min(depth)
    print "max depth: ", np.max(depth)
    #img[:,:,1] = np.array(G).reshape(img.shape[0],-1)

    return img


def exr2flow(exr, w,h):
    file = OpenEXR.InputFile(exr)

    # Compute the size
    dw = file.header()['dataWindow']
    sz = (dw.max.x - dw.min.x + 1, dw.max.y - dw.min.y + 1)

    # Read the three color channels as 32-bit floats
    FLOAT = Imath.PixelType(Imath.PixelType.FLOAT)
    (R,G,B) = [array.array('f', file.channel(Chan, FLOAT)).tolist() for Chan in ("R", "G", "B") ]

    img = np.zeros((h,w,3), np.float64)
    img[:,:,0] = np.array(R).reshape(img.shape[0],-1)
    img[:,:,1] = np.array(G).reshape(img.shape[0],-1)

    hsv = np.zeros((h,w,3), np.uint8)
    hsv[...,1] = 255

    mag, ang = cv2.cartToPolar(img[...,0], img[...,1])
    #mag, ang = cv2.cartToPolar(R, G)
    hsv[...,0] = ang*180/np.pi/2
    hsv[...,2] = cv2.normalize(mag,None,0,255,cv2.NORM_MINMAX)
    bgr = cv2.cvtColor(hsv,cv2.COLOR_HSV2BGR)

    return img, bgr, mag,ang

